==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/ka_GE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "პრევიუს ჩატვირთვა…",
    "Saved" : "შენახულია",
    "Admin" : "ადმინისტრაცია",
    "a safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
    "Name cannot be empty" : "სახელი ვერ იქნება ცარიელი",
    "The given name is too long" : "მოცემული სახელი ძალიან გრძელია",
    "The given web address is too long" : "მოცემული ვებ-მისამართი ძალიან გრძელია",
    "The given slogan is too long" : "მოცემული ლოზუნგი ძალიან გრძელია",
    "The given color is invalid" : "მოცემული ფერი არასწორია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "No file uploaded" : "ფაილი არ იქნა ატვირთული",
    "Unsupported image type" : "ამ სურათის სახეობა არაა მხარდაჭერილი",
    "Theming" : "ვიზუალური თემები",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "ვიზუალური თემები საშუალებას გაძლევთ თქვენს ინსტანციას და მხარდაჭერილ კლიენტებს მარტივად გაუწიოთ გამოსახულებას პერსონალიზაცია. ეს გამოჩნდება ყველა მომხმარებელთან.",
    "Name" : "სახელი",
    "Reset to default" : "საწყის მდგომარეობაში დაბრუნება",
    "Slogan" : "ლოზუნგი",
    "Color" : "ფერი",
    "Logo" : "ლოგო",
    "Upload new logo" : "ახალი ლოგოს ატვირთვა",
    "Login image" : "ლოგინის სურათი",
    "Upload new login background" : "ლოგინის ახალი ფონის ატვირთვა",
    "Remove background image" : "ფონური სურათის მოშორება",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "SVG სურთების მხარდაჭერის მქონე Imagemagick PHP გაფართოების დაყენება ფავიკონებს  ატვირთული ლოგოსა და ფერის მიხევით დააგენერირებს ავტომატურად.",
    "You are already using a custom theme" : "თქვენ პერზონალიზირებულ ვიზუალურ თემას უკვე იყენებთ",
    "reset to default" : "დაბრუნება საწყისზე",
    "Web address" : "ვებ-მისამართი",
    "Web address https://…" : "ვებ მისამართ https://…",
    "There is no error, the file uploaded with success" : "ეს არაა შეცდომა, ფაილი წარმატებით აიტვირთა",
    "The uploaded file was only partially uploaded" : "ფაილი აიტვირთა მხოლოდ ნაწილობრივ",
    "Failed to write file to disk." : "ფაილი დისკზე ვერ ჩაიწერა.",
    "A PHP extension stopped the file upload." : "PHP გაფართოებამ შეაჩერა ფაილის ატვირთვა."
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/ka_GE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "პრევიუს ჩატვირთვა…",
    "Saved" : "შენახულია",
    "Admin" : "ადმინისტრაცია",
    "a safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
    "Name cannot be empty" : "სახელი ვერ იქნება ცარიელი",
    "The given name is too long" : "მოცემული სახელი ძალიან გრძელია",
    "The given web address is too long" : "მოცემული ვებ-მისამართი ძალიან გრძელია",
    "The given slogan is too long" : "მოცემული ლოზუნგი ძალიან გრძელია",
    "The given color is invalid" : "მოცემული ფერი არასწორია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "No file uploaded" : "ფაილი არ იქნა ატვირთული",
    "Theming" : "ვიზუალური თემები",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "ვიზუალური თემები საშუალებას გაძლევთ თქვენს ინსტანციას და მხარდაჭერილ კლიენტებს მარტივად გაუწიოთ გამოსახულებას პერსონალიზაცია. ეს გამოჩნდება ყველა მომხმარებელთან.",
    "Name" : "სახელი",
    "Reset to default" : "საწყის მდგომარეობაში დაბრუნება",
    "Slogan" : "ლოზუნგი",
    "Color" : "ფერი",
    "Logo" : "ლოგო",
    "Upload new logo" : "ახალი ლოგოს ატვირთვა",
    "Login image" : "ლოგინის სურათი",
    "Upload new login background" : "ლოგინის ახალი ფონის ატვირთვა",
    "Remove background image" : "ფონური სურათის მოშორება",
    "Advanced options" : "დამატებითი ოპციონები",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "SVG სურთების მხარდაჭერის მქონე Imagemagick PHP გაფართოების დაყენება ფავიკონებს  ატვირთული ლოგოსა და ფერის მიხევით დააგენერირებს ავტომატურად.",
    "Unsupported image type" : "ამ სურათის სახეობა არაა მხარდაჭერილი"
},
"nplurals=2; plural=(n!=1);");
